==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.6-1.2.8.tar.gz: archive_mail/setup.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.6
    Purpose ........ Allows you to download your email in a zip

*******************************************************************************/

   if (function_exists('sqgetGlobalVar')) {
      if (!defined('SM_PATH'))
         define('SM_PATH','../../');
   } else {
      if (!defined('SM_PATH'))
         define('SM_PATH','../');
   }
   
   function squirrelmail_plugin_init_archive_mail() {
      global $squirrelmail_plugin_hooks;
      $squirrelmail_plugin_hooks['mailbox_index_after']['archive_mail'] = 'archive_mail';
      if (@!function_exists('gzcompress'))
	   return;
      $squirrelmail_plugin_hooks['options_display_inside']['archive_mail'] = 'archive_mail_display_inside';
      $squirrelmail_plugin_hooks['options_display_save']['archive_mail'] = 'archive_mail_display_save';
      $squirrelmail_plugin_hooks['loading_prefs']['archive_mail'] = 'archive_mail_loading_prefs';
   }

   function archive_mail_version() {
      return 0.6;
   }

   function archive_mail() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/archive_mail.php');
   }

   function archive_mail_display_inside() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/display_inside.php');
   }

   function archive_mail_display_save() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/display_save.php');
   }

   function archive_mail_loading_prefs() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/loading_prefs.php');
   }

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.7-1.4.0.tar.gz: archive_mail/setup.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.7
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/

   if (!defined('SM_PATH'))
      define('SM_PATH','../../');

   function squirrelmail_plugin_init_archive_mail() {
      global $squirrelmail_plugin_hooks;
      $squirrelmail_plugin_hooks['mailbox_index_after']['archive_mail'] = 'archive_mail';
      if (@!function_exists('gzcompress'))
	   return;
      $squirrelmail_plugin_hooks['optpage_register_block']['archive_mail'] = 'archive_mail_display_option';
      $squirrelmail_plugin_hooks['loading_prefs']['archive_mail'] = 'archive_mail_loading_prefs';
      $squirrelmail_plugin_hooks['move_before_move']['archive_mail'] = 'archive_mail_zipit';
   }

   function archive_mail_zipit() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/zipit.php');
   }

   function archive_mail_version() {
      return 0.7;
   }

   function archive_mail() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/archive_mail.php');
   }

   function archive_mail_display_option() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/display_options.php');
   }

   function archive_mail_loading_prefs() {
      include_once(SM_PATH . 'plugins/archive_mail/includes/loading_prefs.php');
   }
?>
